#!/bin/sh

# Build script for Minicomputer
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://minicomputer.sourceforge.net/


set -e


SOFTNAME=minicomputer
ALTERNATE_NAME=MinicomputerV
VERSION=1.41
ZENVER=64
BUILD=1
CATEGORY=extra/xap

MARCH=i686
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/${ALTERNATE_NAME}${VERSION}
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep
LOG=$PKGDIR.log

SRCFILES=(
	${ALTERNATE_NAME}${VERSION}.tar.gz
	$SOFTNAME.patch
	$SOFTNAME.png
)
SRCURLS=(
	http://downloads.sourceforge.net/minicomputer
	http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
	${SRCURLS[1]}/${SRCFILES[1]}
	${SRCURLS[1]}/${SRCFILES[2]}
)

DOC=(
	$SOFTDIR/CHANGES
	$SOFTDIR/COPYING
	$SOFTDIR/README
)

EXTRADEPS=(
)

LESSDEPS=(
	fakeroot
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi

if [ ! -f ${SRCFILES[1]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[1]}
fi

if [ ! -f ${SRCFILES[2]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[2]}
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $LOG
mkdir -p $PKG


# Build

build () {
	
	echo ""
	echo "-----Building-----"
	echo ""
	
	mkdir $SOFTDIR
	tar -xvf $CWD/${SRCFILES[0]} -C $SOFTDIR

	cd $SOFTDIR
	
	patch -p1 < $CWD/${SRCFILES[1]}
	sed -i "s:PKGDIR:$PKGDIR:g" SConstruct
	sed -i "s:PKGDIR:$PKGDIR:g" installpresets.sh
	
	scons -j2
	scons install


	mkdir -p $PKGDIR/usr/share/icons/hicolor/48x48/apps
	mkdir -p $PKGDIR/usr/share/applications

	sh installpresets.sh

	mv -v $PKGDIR/usr/bin/minicomputer \
		$PKGDIR/usr/bin/minicomputer-bin
	
	cat << EOF > $PKGDIR/usr/bin/minicomputer
#!/bin/sh
if [[ ! -d \$HOME/.miniComputer ]]; then
cp -rvf /usr/share/minicomputer/.miniComputer \$HOME/
fi
/usr/bin/minicomputer-bin \$*
EOF
	chmod 755 $PKGDIR/usr/bin/minicomputer

	cp -v $CWD/${SRCFILES[2]} \
		$PKGDIR/usr/share/icons/hicolor/48x48/apps/

	cat << EOF > $PKGDIR/usr/share/applications/minicomputer.desktop
[Desktop Entry]
Name=Minicomputer
Comment=Industrial Grade Digital Synthesizer for Linux
Icon=minicomputer
Exec=minicomputer
Terminal=false
Type=Application
Encoding=UTF-8
Categories=GTK;Audio;AudioVideo;AudioVideoEditing;Multimedia
EOF
	

}


# Packaging

packaging () {
	
	echo ""
	echo "-----Packaging-----"
	echo ""
	
	( cd $PKG

	mkdir -p $PKGDIR/install
	mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
	mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


           #|-----handy-ruler------------------------------------------------------|
	cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME - Industrial Grade Digital Synthesizer for Linux
$SOFTNAME:
$SOFTNAME: Minicomputer is a standalone Linux softwaresynthesizer for creating
$SOFTNAME: experimental electronic sounds as its often used in but not limited
$SOFTNAME: to Industrial music, IDM, EBM, Glitch, sound design and minimal
$SOFTNAME: electronic. It is monophonic but can produce up to 8 different sounds
$SOFTNAME: at the same time.
$SOFTNAME: It uses Jack as realtime audio infrastructure and can be controlled
$SOFTNAME: via Midi.
$SOFTNAME: 
$SOFTNAME: 
EOF

	
	# Redundent
	
	if [ -d $PKGDIR/usr/share/doc ]; then
		mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
		rm -rvf $PKGDIR/usr/share/doc
	fi
	
	if [ -d $PKGDIR/etc ]; then
		if [ $DOTNEW == 1 ]; then
			find $PKGDIR/etc -type f -exec \
				mv {} {}.new \;
		fi
	fi

	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null || true
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null || true

	if [ -d $PKGDIR/usr/man ]; then
		
		( cd $PKGDIR/usr/man
			find . -type f -exec gzip -9 {} \;
			for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
		)
		
	fi

	if [ -d $PKGDIR/usr/info ]; then
		
		rm -f $PKGDIR/usr/info/dir
		gzip -9 $PKGDIR/usr/info/*.info*
		
	fi

	find . -name perllocal.pod \
		-o -name ".packlist" \
		-o -name "*.bs" \
		| xargs rm -f


	cp -v $CWD/build-$SOFTNAME.sh \
		$CWD/${SRCFILES[1]} \
		$CWD/${SRCFILES[2]} \
		$PKGDIR/usr/src/$SOFTNAME-$VERSION/

	cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


	# fix permissions and ownership
	chown -R root:root .
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;


	/sbin/makepkg -l y -c n $PKGFILE )


	echo 'Creating .md5 file'
	md5sum $PKG.txz > $MD5

	echo 'Creating .src file'
	for link in ${SRCLINKS[@]}; do
		echo $link >> $SRC
	done

	echo 'Checking for dependencies'
	deps=$(depfinder $PKGFILE)
	
	for dep in ${EXTRADEPS[@]}; do
		deps="$deps,$dep"
	done
	
	for dep in ${LESSDEPS[@]}; do
		deps=${deps/$dep/}
	done
	
	order=$(echo ${deps//,/ } | sort -d)
	echo ${order// /,} > $DEP

	echo "Removing build directories"
	rm -rf $SOFTDIR $PKG
	
}


LANG=C build 2>&1 | tee $LOG
LANG=C packaging 2>&1 | tee -a $LOG
